==> aws-cdk-lib-2.0.0-rc.20-sources.jar: software/amazon/awscdk/services/config/CfnDeliveryChannelProps.java <==
package software.amazon.awscdk.services.config;

/**
 * Properties for defining a `AWS::Config::DeliveryChannel`.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.31.0 (build 6fa403d)", date = "2021-09-01T10:26:16.401Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.$Module.class, fqn = "aws-cdk-lib.aws_config.CfnDeliveryChannelProps")
@software.amazon.jsii.Jsii.Proxy(CfnDeliveryChannelProps.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface CfnDeliveryChannelProps extends software.amazon.jsii.JsiiSerializable {

    /**
     * `AWS::Config::DeliveryChannel.S3BucketName`.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getS3BucketName();

    /**
     * `AWS::Config::DeliveryChannel.ConfigSnapshotDeliveryProperties`.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.Object getConfigSnapshotDeliveryProperties() {
        return null;
    }

    /**
     * `AWS::Config::DeliveryChannel.Name`.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.String getName() {
        return null;
    }

    /**
     * `AWS::Config::DeliveryChannel.S3KeyPrefix`.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.String getS3KeyPrefix() {
        return null;
    }

    /**
     * `AWS::Config::DeliveryChannel.S3KmsKeyArn`.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.String getS3KmsKeyArn() {
        return null;
    }

    /**
     * `AWS::Config::DeliveryChannel.SnsTopicARN`.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.String getSnsTopicArn() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link CfnDeliveryChannelProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link CfnDeliveryChannelProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<CfnDeliveryChannelProps> {
        private java.lang.String s3BucketName;
        private java.lang.Object configSnapshotDeliveryProperties;
        private java.lang.String name;
        private java.lang.String s3KeyPrefix;
        private java.lang.String s3KmsKeyArn;
        private java.lang.String snsTopicArn;

        /**
         * Sets the value of {@link CfnDeliveryChannelProps#getS3BucketName}
         * @param s3BucketName `AWS::Config::DeliveryChannel.S3BucketName`. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder s3BucketName(java.lang.String s3BucketName) {
            this.s3BucketName = s3BucketName;
            return this;
        }

        /**
         * Sets the value of {@link CfnDeliveryChannelProps#getConfigSnapshotDeliveryProperties}
         * @param configSnapshotDeliveryProperties `AWS::Config::DeliveryChannel.ConfigSnapshotDeliveryProperties`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder configSnapshotDeliveryProperties(software.amazon.awscdk.services.config.CfnDeliveryChannel.ConfigSnapshotDeliveryPropertiesProperty configSnapshotDeliveryProperties) {
            this.configSnapshotDeliveryProperties = configSnapshotDeliveryProperties;
            return this;
        }

        /**
         * Sets the value of {@link CfnDeliveryChannelProps#getConfigSnapshotDeliveryProperties}
         * @param configSnapshotDeliveryProperties `AWS::Config::DeliveryChannel.ConfigSnapshotDeliveryProperties`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder configSnapshotDeliveryProperties(software.amazon.awscdk.IResolvable configSnapshotDeliveryProperties) {
            this.configSnapshotDeliveryProperties = configSnapshotDeliveryProperties;
            return this;
        }

        /**
         * Sets the value of {@link CfnDeliveryChannelProps#getName}
         * @param name `AWS::Config::DeliveryChannel.Name`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder name(java.lang.String name) {
            this.name = name;
            return this;
        }

        /**
         * Sets the value of {@link CfnDeliveryChannelProps#getS3KeyPrefix}
         * @param s3KeyPrefix `AWS::Config::DeliveryChannel.S3KeyPrefix`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder s3KeyPrefix(java.lang.String s3KeyPrefix) {
            this.s3KeyPrefix = s3KeyPrefix;
            return this;
        }

        /**
         * Sets the value of {@link CfnDeliveryChannelProps#getS3KmsKeyArn}
         * @param s3KmsKeyArn `AWS::Config::DeliveryChannel.S3KmsKeyArn`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder s3KmsKeyArn(java.lang.String s3KmsKeyArn) {
            this.s3KmsKeyArn = s3KmsKeyArn;
            return this;
        }

        /**
         * Sets the value of {@link CfnDeliveryChannelProps#getSnsTopicArn}
         * @param snsTopicArn `AWS::Config::DeliveryChannel.SnsTopicARN`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder snsTopicArn(java.lang.String snsTopicArn) {
            this.snsTopicArn = snsTopicArn;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link CfnDeliveryChannelProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public CfnDeliveryChannelProps build() {
            return new Jsii$Proxy(s3BucketName, configSnapshotDeliveryProperties, name, s3KeyPrefix, s3KmsKeyArn, snsTopicArn);
        }
    }

    /**
     * An implementation for {@link CfnDeliveryChannelProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements CfnDeliveryChannelProps {
        private final java.lang.String s3BucketName;
        private final java.lang.Object configSnapshotDeliveryProperties;
        private final java.lang.String name;
        private final java.lang.String s3KeyPrefix;
        private final java.lang.String s3KmsKeyArn;
        private final java.lang.String snsTopicArn;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.s3BucketName = software.amazon.jsii.Kernel.get(this, "s3BucketName", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.configSnapshotDeliveryProperties = software.amazon.jsii.Kernel.get(this, "configSnapshotDeliveryProperties", software.amazon.jsii.NativeType.forClass(java.lang.Object.class));
            this.name = software.amazon.jsii.Kernel.get(this, "name", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.s3KeyPrefix = software.amazon.jsii.Kernel.get(this, "s3KeyPrefix", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.s3KmsKeyArn = software.amazon.jsii.Kernel.get(this, "s3KmsKeyArn", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.snsTopicArn = software.amazon.jsii.Kernel.get(this, "snsTopicArn", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final java.lang.String s3BucketName, final java.lang.Object configSnapshotDeliveryProperties, final java.lang.String name, final java.lang.String s3KeyPrefix, final java.lang.String s3KmsKeyArn, final java.lang.String snsTopicArn) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.s3BucketName = java.util.Objects.requireNonNull(s3BucketName, "s3BucketName is required");
            this.configSnapshotDeliveryProperties = configSnapshotDeliveryProperties;
            this.name = name;
            this.s3KeyPrefix = s3KeyPrefix;
            this.s3KmsKeyArn = s3KmsKeyArn;
            this.snsTopicArn = snsTopicArn;
        }

        @Override
        public final java.lang.String getS3BucketName() {
            return this.s3BucketName;
        }

        @Override
        public final java.lang.Object getConfigSnapshotDeliveryProperties() {
            return this.configSnapshotDeliveryProperties;
        }

        @Override
        public final java.lang.String getName() {
            return this.name;
        }

        @Override
        public final java.lang.String getS3KeyPrefix() {
            return this.s3KeyPrefix;
        }

        @Override
        public final java.lang.String getS3KmsKeyArn() {
            return this.s3KmsKeyArn;
        }

        @Override
        public final java.lang.String getSnsTopicArn() {
            return this.snsTopicArn;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("s3BucketName", om.valueToTree(this.getS3BucketName()));
            if (this.getConfigSnapshotDeliveryProperties() != null) {
                data.set("configSnapshotDeliveryProperties", om.valueToTree(this.getConfigSnapshotDeliveryProperties()));
            }
            if (this.getName() != null) {
                data.set("name", om.valueToTree(this.getName()));
            }
            if (this.getS3KeyPrefix() != null) {
                data.set("s3KeyPrefix", om.valueToTree(this.getS3KeyPrefix()));
            }
            if (this.getS3KmsKeyArn() != null) {
                data.set("s3KmsKeyArn", om.valueToTree(this.getS3KmsKeyArn()));
            }
            if (this.getSnsTopicArn() != null) {
                data.set("snsTopicArn", om.valueToTree(this.getSnsTopicArn()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("aws-cdk-lib.aws_config.CfnDeliveryChannelProps"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            CfnDeliveryChannelProps.Jsii$Proxy that = (CfnDeliveryChannelProps.Jsii$Proxy) o;

            if (!s3BucketName.equals(that.s3BucketName)) return false;
            if (this.configSnapshotDeliveryProperties != null ? !this.configSnapshotDeliveryProperties.equals(that.configSnapshotDeliveryProperties) : that.configSnapshotDeliveryProperties != null) return false;
            if (this.name != null ? !this.name.equals(that.name) : that.name != null) return false;
            if (this.s3KeyPrefix != null ? !this.s3KeyPrefix.equals(that.s3KeyPrefix) : that.s3KeyPrefix != null) return false;
            if (this.s3KmsKeyArn != null ? !this.s3KmsKeyArn.equals(that.s3KmsKeyArn) : that.s3KmsKeyArn != null) return false;
            return this.snsTopicArn != null ? this.snsTopicArn.equals(that.snsTopicArn) : that.snsTopicArn == null;
        }

        @Override
        public final int hashCode() {
            int result = this.s3BucketName.hashCode();
            result = 31 * result + (this.configSnapshotDeliveryProperties != null ? this.configSnapshotDeliveryProperties.hashCode() : 0);
            result = 31 * result + (this.name != null ? this.name.hashCode() : 0);
            result = 31 * result + (this.s3KeyPrefix != null ? this.s3KeyPrefix.hashCode() : 0);
            result = 31 * result + (this.s3KmsKeyArn != null ? this.s3KmsKeyArn.hashCode() : 0);
            result = 31 * result + (this.snsTopicArn != null ? this.snsTopicArn.hashCode() : 0);
            return result;
        }
    }
}

==> aws-cdk-lib-2.10.0-sources.jar: software/amazon/awscdk/services/config/CfnDeliveryChannelProps.java <==
package software.amazon.awscdk.services.config;

/**
 * Properties for defining a `CfnDeliveryChannel`.
 * <p>
 * Example:
 * <p>
 * <blockquote><pre>
 * // The code below shows an example of how to instantiate this type.
 * // The values are placeholders you should change.
 * import software.amazon.awscdk.services.config.*;
 * CfnDeliveryChannelProps cfnDeliveryChannelProps = CfnDeliveryChannelProps.builder()
 *         .s3BucketName("s3BucketName")
 *         // the properties below are optional
 *         .configSnapshotDeliveryProperties(ConfigSnapshotDeliveryPropertiesProperty.builder()
 *                 .deliveryFrequency("deliveryFrequency")
 *                 .build())
 *         .name("name")
 *         .s3KeyPrefix("s3KeyPrefix")
 *         .s3KmsKeyArn("s3KmsKeyArn")
 *         .snsTopicArn("snsTopicArn")
 *         .build();
 * </pre></blockquote>
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.52.1 (build 5ccc8f6)", date = "2022-01-29T04:34:08.614Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.$Module.class, fqn = "aws-cdk-lib.aws_config.CfnDeliveryChannelProps")
@software.amazon.jsii.Jsii.Proxy(CfnDeliveryChannelProps.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface CfnDeliveryChannelProps extends software.amazon.jsii.JsiiSerializable {

    /**
     * The name of the Amazon S3 bucket to which AWS Config delivers configuration snapshots and configuration history files.
     * <p>
     * If you specify a bucket that belongs to another AWS account , that bucket must have policies that grant access permissions to AWS Config . For more information, see <a href="https://docs.aws.amazon.com/config/latest/developerguide/s3-bucket-policy.html">Permissions for the Amazon S3 Bucket</a> in the AWS Config Developer Guide.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getS3BucketName();

    /**
     * The options for how often AWS Config delivers configuration snapshots to the Amazon S3 bucket.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.Object getConfigSnapshotDeliveryProperties() {
        return null;
    }

    /**
     * A name for the delivery channel.
     * <p>
     * If you don't specify a name, AWS CloudFormation generates a unique physical ID and uses that ID for the delivery channel name. For more information, see <a href="https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-name.html">Name Type</a> .
     * <p>
     * Updates are not supported. To change the name, you must run two separate updates. In the first update, delete this resource, and then recreate it with a new name in the second update.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.String getName() {
        return null;
    }

    /**
     * The prefix for the specified Amazon S3 bucket.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.String getS3KeyPrefix() {
        return null;
    }

    /**
     * The Amazon Resource Name (ARN) of the AWS Key Management Service ( AWS KMS ) AWS KMS key (KMS key) used to encrypt objects delivered by AWS Config .
     * <p>
     * Must belong to the same Region as the destination S3 bucket.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.String getS3KmsKeyArn() {
        return null;
    }

    /**
     * The Amazon Resource Name (ARN) of the Amazon SNS topic to which AWS Config sends notifications about configuration changes.
     * <p>
     * If you choose a topic from another account, the topic must have policies that grant access permissions to AWS Config . For more information, see <a href="https://docs.aws.amazon.com/config/latest/developerguide/sns-topic-policy.html">Permissions for the Amazon SNS Topic</a> in the AWS Config Developer Guide.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.String getSnsTopicArn() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link CfnDeliveryChannelProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link CfnDeliveryChannelProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<CfnDeliveryChannelProps> {
        java.lang.String s3BucketName;
        java.lang.Object configSnapshotDeliveryProperties;
        java.lang.String name;
        java.lang.String s3KeyPrefix;
        java.lang.String s3KmsKeyArn;
        java.lang.String snsTopicArn;

        /**
         * Sets the value of {@link CfnDeliveryChannelProps#getS3BucketName}
         * @param s3BucketName The name of the Amazon S3 bucket to which AWS Config delivers configuration snapshots and configuration history files. This parameter is required.
         *                     If you specify a bucket that belongs to another AWS account , that bucket must have policies that grant access permissions to AWS Config . For more information, see <a href="https://docs.aws.amazon.com/config/latest/developerguide/s3-bucket-policy.html">Permissions for the Amazon S3 Bucket</a> in the AWS Config Developer Guide.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder s3BucketName(java.lang.String s3BucketName) {
            this.s3BucketName = s3BucketName;
            return this;
        }

        /**
         * Sets the value of {@link CfnDeliveryChannelProps#getConfigSnapshotDeliveryProperties}
         * @param configSnapshotDeliveryProperties The options for how often AWS Config delivers configuration snapshots to the Amazon S3 bucket.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder configSnapshotDeliveryProperties(software.amazon.awscdk.services.config.CfnDeliveryChannel.ConfigSnapshotDeliveryPropertiesProperty configSnapshotDeliveryProperties) {
            this.configSnapshotDeliveryProperties = configSnapshotDeliveryProperties;
            return this;
        }

        /**
         * Sets the value of {@link CfnDeliveryChannelProps#getConfigSnapshotDeliveryProperties}
         * @param configSnapshotDeliveryProperties The options for how often AWS Config delivers configuration snapshots to the Amazon S3 bucket.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder configSnapshotDeliveryProperties(software.amazon.awscdk.IResolvable configSnapshotDeliveryProperties) {
            this.configSnapshotDeliveryProperties = configSnapshotDeliveryProperties;
            return this;
        }

        /**
         * Sets the value of {@link CfnDeliveryChannelProps#getName}
         * @param name A name for the delivery channel.
         *             If you don't specify a name, AWS CloudFormation generates a unique physical ID and uses that ID for the delivery channel name. For more information, see <a href="https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-name.html">Name Type</a> .
         *             <p>
         *             Updates are not supported. To change the name, you must run two separate updates. In the first update, delete this resource, and then recreate it with a new name in the second update.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder name(java.lang.String name) {
            this.name = name;
            return this;
        }

        /**
         * Sets the value of {@link CfnDeliveryChannelProps#getS3KeyPrefix}
         * @param s3KeyPrefix The prefix for the specified Amazon S3 bucket.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder s3KeyPrefix(java.lang.String s3KeyPrefix) {
            this.s3KeyPrefix = s3KeyPrefix;
            return this;
        }

        /**
         * Sets the value of {@link CfnDeliveryChannelProps#getS3KmsKeyArn}
         * @param s3KmsKeyArn The Amazon Resource Name (ARN) of the AWS Key Management Service ( AWS KMS ) AWS KMS key (KMS key) used to encrypt objects delivered by AWS Config .
         *                    Must belong to the same Region as the destination S3 bucket.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder s3KmsKeyArn(java.lang.String s3KmsKeyArn) {
            this.s3KmsKeyArn = s3KmsKeyArn;
            return this;
        }

        /**
         * Sets the value of {@link CfnDeliveryChannelProps#getSnsTopicArn}
         * @param snsTopicArn The Amazon Resource Name (ARN) of the Amazon SNS topic to which AWS Config sends notifications about configuration changes.
         *                    If you choose a topic from another account, the topic must have policies that grant access permissions to AWS Config . For more information, see <a href="https://docs.aws.amazon.com/config/latest/developerguide/sns-topic-policy.html">Permissions for the Amazon SNS Topic</a> in the AWS Config Developer Guide.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder snsTopicArn(java.lang.String snsTopicArn) {
            this.snsTopicArn = snsTopicArn;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link CfnDeliveryChannelProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public CfnDeliveryChannelProps build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link CfnDeliveryChannelProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements CfnDeliveryChannelProps {
        private final java.lang.String s3BucketName;
        private final java.lang.Object configSnapshotDeliveryProperties;
        private final java.lang.String name;
        private final java.lang.String s3KeyPrefix;
        private final java.lang.String s3KmsKeyArn;
        private final java.lang.String snsTopicArn;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.s3BucketName = software.amazon.jsii.Kernel.get(this, "s3BucketName", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.configSnapshotDeliveryProperties = software.amazon.jsii.Kernel.get(this, "configSnapshotDeliveryProperties", software.amazon.jsii.NativeType.forClass(java.lang.Object.class));
            this.name = software.amazon.jsii.Kernel.get(this, "name", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.s3KeyPrefix = software.amazon.jsii.Kernel.get(this, "s3KeyPrefix", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.s3KmsKeyArn = software.amazon.jsii.Kernel.get(this, "s3KmsKeyArn", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.snsTopicArn = software.amazon.jsii.Kernel.get(this, "snsTopicArn", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.s3BucketName = java.util.Objects.requireNonNull(builder.s3BucketName, "s3BucketName is required");
            this.configSnapshotDeliveryProperties = builder.configSnapshotDeliveryProperties;
            this.name = builder.name;
            this.s3KeyPrefix = builder.s3KeyPrefix;
            this.s3KmsKeyArn = builder.s3KmsKeyArn;
            this.snsTopicArn = builder.snsTopicArn;
        }

        @Override
        public final java.lang.String getS3BucketName() {
            return this.s3BucketName;
        }

        @Override
        public final java.lang.Object getConfigSnapshotDeliveryProperties() {
            return this.configSnapshotDeliveryProperties;
        }

        @Override
        public final java.lang.String getName() {
            return this.name;
        }

        @Override
        public final java.lang.String getS3KeyPrefix() {
            return this.s3KeyPrefix;
        }

        @Override
        public final java.lang.String getS3KmsKeyArn() {
            return this.s3KmsKeyArn;
        }

        @Override
        public final java.lang.String getSnsTopicArn() {
            return this.snsTopicArn;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("s3BucketName", om.valueToTree(this.getS3BucketName()));
            if (this.getConfigSnapshotDeliveryProperties() != null) {
                data.set("configSnapshotDeliveryProperties", om.valueToTree(this.getConfigSnapshotDeliveryProperties()));
            }
            if (this.getName() != null) {
                data.set("name", om.valueToTree(this.getName()));
            }
            if (this.getS3KeyPrefix() != null) {
                data.set("s3KeyPrefix", om.valueToTree(this.getS3KeyPrefix()));
            }
            if (this.getS3KmsKeyArn() != null) {
                data.set("s3KmsKeyArn", om.valueToTree(this.getS3KmsKeyArn()));
            }
            if (this.getSnsTopicArn() != null) {
                data.set("snsTopicArn", om.valueToTree(this.getSnsTopicArn()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("aws-cdk-lib.aws_config.CfnDeliveryChannelProps"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            CfnDeliveryChannelProps.Jsii$Proxy that = (CfnDeliveryChannelProps.Jsii$Proxy) o;

            if (!s3BucketName.equals(that.s3BucketName)) return false;
            if (this.configSnapshotDeliveryProperties != null ? !this.configSnapshotDeliveryProperties.equals(that.configSnapshotDeliveryProperties) : that.configSnapshotDeliveryProperties != null) return false;
            if (this.name != null ? !this.name.equals(that.name) : that.name != null) return false;
            if (this.s3KeyPrefix != null ? !this.s3KeyPrefix.equals(that.s3KeyPrefix) : that.s3KeyPrefix != null) return false;
            if (this.s3KmsKeyArn != null ? !this.s3KmsKeyArn.equals(that.s3KmsKeyArn) : that.s3KmsKeyArn != null) return false;
            return this.snsTopicArn != null ? this.snsTopicArn.equals(that.snsTopicArn) : that.snsTopicArn == null;
        }

        @Override
        public final int hashCode() {
            int result = this.s3BucketName.hashCode();
            result = 31 * result + (this.configSnapshotDeliveryProperties != null ? this.configSnapshotDeliveryProperties.hashCode() : 0);
            result = 31 * result + (this.name != null ? this.name.hashCode() : 0);
            result = 31 * result + (this.s3KeyPrefix != null ? this.s3KeyPrefix.hashCode() : 0);
            result = 31 * result + (this.s3KmsKeyArn != null ? this.s3KmsKeyArn.hashCode() : 0);
            result = 31 * result + (this.snsTopicArn != null ? this.snsTopicArn.hashCode() : 0);
            return result;
        }
    }
}
